financial_chart
A interactive chart library for Flutter, supports various types of charts commonly used in financial apps, high performance and easy to customize and extend.
Try live demo

Features
- Supports OHLC, candlestick, line, area, bar, and stacked bar charts.
- Provides markers for graphs and axes, including labels, lines, arrows, callouts, shapes, and more.
- Easily extensible for custom graph types and markers.
- Resizable panels with support for multiple graphs and axes per panel.
- Supports both linear and logarithmic value axes.
- Displays tooltips and crosshair lines for data points.
- Zoom and pan functionality for axes and graphs and momentum scrolling supported.
- Animated transitions when zooming.
- Dynamic data loading with loading indicators.
- Real-time data and graph updates.
- Customizable themes with dark and light presets.
Usage
License
This project is licensed under the MIT License.
Libraries
- financial_chart
- A chart library for financial data.