GComponent<T extends GComponentTheme> class abstract

Base class for all visible components.

Mixed-in types
Implementers

Constructors

GComponent({String? id, String? label, bool visible = true, bool highlighted = false, bool selected = false, bool locked = false, int layer = kDefaultLayer, GHitTestMode hitTestMode = GHitTestMode.auto, T? theme, GRender<GComponent<GComponentTheme>, GComponentTheme>? render})

Properties

hashCode int
The hash code for this object.
no setterinherited
highlighted bool
getter/setter pair
highlightedNotifier GValue<bool>
no setter
hitTestEnable bool
no setter
hitTestMode GHitTestMode
getter/setter pair
hitTestModeNotifier GValue<GHitTestMode>
no setter
id String?
Identifier of the component.
final
label String?
getter/setter pair
labelNotifier GValue<String?>
no setter
layer int
getter/setter pair
layerNotifier GValue<int>
no setter
locked bool
getter/setter pair
lockedNotifier GValue<bool>
no setter
render GRender<GComponent<GComponentTheme>, GComponentTheme>?
Render of the component.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pair
selectedNotifier GValue<bool>
no setter
theme ↔ T?
getter/setter pair
visible bool
getter/setter pair
visibleNotifier GValue<bool>
no setter

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
getRender() GRender<GComponent<GComponentTheme>, GComponentTheme>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kDefaultLayer → const int