GGraphBar<T extends GGraphTheme> class

Bar graph.

Inheritance

Constructors

GGraphBar({String? id, String? label, required String valueKey, double? baseValue, double basePosition = 1.0, int layer = kDefaultLayer, bool visible = true, bool highlighted = false, bool selected = false, String valueViewPortId = "", GHitTestMode hitTestMode = GHitTestMode.auto, List<String>? crosshairHighlightValueKeys, List<GOverlayMarker> overlayMarkers = const [], T? theme, GGraphRender<GGraph<GGraphTheme>, GGraphTheme>? render})

Properties

basePosition double
getter/setter pair
baseValue double?
getter/setter pair
crosshairHighlightValueKeys List<String>
The keys of the series value in the data source that will be highlighted by drawing a circle on the graph.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
highlighted bool
getter/setter pairinherited
highlightedNotifier GValue<bool>
no setterinherited
hitTestEnable bool
no setterinherited
hitTestMode GHitTestMode
getter/setter pairinherited
hitTestModeNotifier GValue<GHitTestMode>
no setterinherited
id String?
Identifier of the component.
finalinherited
label String?
getter/setter pairinherited
labelNotifier GValue<String?>
no setterinherited
layer int
getter/setter pairinherited
layerNotifier GValue<int>
no setterinherited
locked bool
getter/setter pairinherited
lockedNotifier GValue<bool>
no setterinherited
overlayMarkers List<GOverlayMarker>
The graph markers of the graph.
no setterinherited
render GRender<GComponent<GComponentTheme>, GComponentTheme>?
Render of the component.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pairinherited
selectedNotifier GValue<bool>
no setterinherited
theme GComponentTheme?
getter/setter pairinherited
type String
no setteroverride
valueKey String
The key of the series value in the data source.
final
valueViewPortId String
The value viewport id of the graph.
finalinherited
visible bool
getter/setter pairinherited
visibleNotifier GValue<bool>
no setterinherited

Methods

addMarker(GOverlayMarker marker) → void
inherited
clearMarkers() → void
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
findMarker(String id) GOverlayMarker?
inherited
getRender() GRender<GComponent<GComponentTheme>, GComponentTheme>
inherited
hitTestOverlayMarkers({required Offset position}) GOverlayMarker?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeMarker(GOverlayMarker marker) bool
inherited
removeMarkerById(String id) GOverlayMarker?
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

typeName → const String