GGraphGridsRender class

Inheritance

Constructors

GGraphGridsRender()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hitTestEpsilon double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLinePath({Path? toPath, required double x1, required double y1, required double x2, required double y2, Rect? area, bool startRay = false, bool endRay = false, List<double>? resultPathPoints}) Path
inherited
addOvalPath({Path? toPath, required Rect rect, double cornerRadius = 0}) Path
inherited
addPolygonPath({Path? toPath, required List<Offset> points, required bool close, double cornerRadius = 0}) Path
inherited
addRectPath({Path? toPath, required Rect rect, double cornerRadius = 0}) Path
inherited
doRender({required Canvas canvas, required GChart chart, GPanel? panel, required GGraphGrids<GGraphTheme> component, required Rect area, required GGraphGridsTheme theme}) → void
inherited
doRenderCrosshairHighlightValues({required Canvas canvas, required GChart chart, required GPanel panel, required GGraphGrids<GGraphTheme> graph, required Rect area, required GGraphGridsTheme theme}) → void
inherited
doRenderGraph({required Canvas canvas, required GChart chart, required GPanel panel, required GGraphGrids<GGraphTheme> graph, required Rect area, required GGraphGridsTheme theme, required GPointViewPort pointViewPort, required GValueViewPort valueViewPort}) → void
override
doRenderMarkers({required Canvas canvas, required GChart chart, required GPanel panel, required GGraphGrids<GGraphTheme> graph, required Rect area, required GGraphGridsTheme theme}) → void
inherited
drawCrosshairHighlightMarks({required Canvas canvas, required GGraph<GGraphTheme> graph, required GGraphGridsTheme theme, required List<Vector2> highlightMarks}) → void
Draw the crosshair highlight marks (when the pointer moves).
inherited
drawGraphHighlightMarks({required Canvas canvas, required GGraph<GGraphTheme> graph, required Rect area, required GGraphGridsTheme theme, required List<Vector2> highlightMarks}) → void
Draw the highlight marks (when hit test result is true).
inherited
drawHighlightMarks({required Canvas canvas, required GComponent<GComponentTheme> component, required Rect area, required GGraphHighlightMarkerTheme? highlightMarkerTheme, required List<Vector2> highlightMarks}) → void
Draw the highlight marks (when hit test result is true).
inherited
drawPath({required Canvas canvas, required Path path, required PaintStyle style, bool ignoreDash = false, bool fillOnly = false, bool strokeOnly = false}) → void
inherited
drawPointAxisLabel({required Canvas canvas, required String text, required GPointAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Rect
inherited
drawText({required Canvas canvas, required String text, Offset anchor = Offset.zero, Alignment defaultAlign = Alignment.center, required LabelStyle style}) Rect
inherited
drawValueAxisLabel({required Canvas canvas, required String text, required GValueAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Rect
inherited
getTextBlockPaintPoint(Offset axis, double width, double height, Alignment align) Offset
inherited
hitTest({required Offset position, double? epsilon}) bool
inherited
hitTestLines({required List<List<Vector2>> lines, required Offset position, double? epsilon}) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAxisLabelAlignment({required GPointAxis axis}) Alignment
inherited
pointAxisLabelAnchor({required GPointAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Offset
inherited
render({required Canvas canvas, required GChart chart, GPanel? panel, required GGraphGrids<GGraphTheme> component, required Rect area, required GGraphGridsTheme theme}) → void
inherited
renderClipped({required Canvas canvas, required Rect clipRect, required void render()}) → void
inherited
renderRotated({required Canvas canvas, required Offset center, required double theta, required void render()}) → void
inherited
toString() String
A string representation of this object.
inherited
valueAxisLabelAlignment({required GValueAxis axis}) Alignment
inherited
valueAxisLabelAnchor({required GValueAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Offset
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited