GShapeMarkerRender class

Inheritance

Constructors

GShapeMarkerRender()

Properties

center Offset
getter/setter pair
controlHandles Map<String, GControlHandle>
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hitTestEpsilon double
finalinherited
radius double
getter/setter pair
rotation double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shapePath Path?
getter/setter pair

Methods

addLinePath({Path? toPath, required double x1, required double y1, required double x2, required double y2, Rect? area, bool startRay = false, bool endRay = false, List<double>? resultPathPoints}) Path
inherited
addOvalPath({Path? toPath, required Rect rect, double cornerRadius = 0}) Path
inherited
addPolygonPath({Path? toPath, required List<Offset> points, required bool close, double cornerRadius = 0}) Path
inherited
addRectPath({Path? toPath, required Rect rect, double cornerRadius = 0}) Path
inherited
doRender({required Canvas canvas, required GChart chart, GPanel? panel, required GShapeMarker component, required Rect area, required GOverlayMarkerTheme theme}) → void
inherited
doRenderMarker({required Canvas canvas, required GChart chart, required GPanel panel, required GComponent<GComponentTheme> component, required GShapeMarker marker, required Rect area, required GOverlayMarkerTheme theme, required GPointViewPort pointViewPort, required GValueViewPort valueViewPort}) → void
override
drawControlHandles({required Canvas canvas, required GShapeMarker marker, required GOverlayMarkerTheme theme, required Rect area, required GValueViewPort valueViewPort, required GPointViewPort pointViewPort}) → void
inherited
drawHighlightMarks({required Canvas canvas, required GComponent<GComponentTheme> component, required Rect area, required GGraphHighlightMarkerTheme? highlightMarkerTheme, required List<Vector2> highlightMarks}) → void
Draw the highlight marks (when hit test result is true).
inherited
drawPath({required Canvas canvas, required Path path, required PaintStyle style, bool ignoreDash = false, bool fillOnly = false, bool strokeOnly = false}) → void
inherited
drawPointAxisLabel({required Canvas canvas, required String text, required GPointAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Rect
inherited
drawText({required Canvas canvas, required String text, Offset anchor = Offset.zero, Alignment defaultAlign = Alignment.center, required LabelStyle style}) Rect
inherited
drawValueAxisLabel({required Canvas canvas, required String text, required GValueAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Rect
inherited
getTextBlockPaintPoint(Offset axis, double width, double height, Alignment align) Offset
inherited
hitTest({required Offset position, double? epsilon}) bool
override
hitTestControlHandles({required Offset position, double? epsilon}) bool
inherited
hitTestLines({required List<List<Vector2>> lines, required Offset position, double? epsilon}) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAxisLabelAlignment({required GPointAxis axis}) Alignment
inherited
pointAxisLabelAnchor({required GPointAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Offset
inherited
render({required Canvas canvas, required GChart chart, GPanel? panel, required GShapeMarker component, required Rect area, required GOverlayMarkerTheme theme}) → void
inherited
renderClipped({required Canvas canvas, required Rect clipRect, required void render()}) → void
inherited
renderMarker({required Canvas canvas, required GChart chart, required GPanel panel, required GComponent<GComponentTheme> component, required GShapeMarker marker, required Rect area, required GOverlayMarkerTheme theme, GValueViewPort? valueViewPort}) → void
inherited
renderRotated({required Canvas canvas, required Offset center, required double theta, required void render()}) → void
inherited
toString() String
A string representation of this object.
inherited
valueAxisLabelAlignment({required GValueAxis axis}) Alignment
inherited
valueAxisLabelAnchor({required GValueAxis axis, required double position, required Rect axisArea, required GAxisLabelTheme labelTheme}) Offset
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited