GSplitterTheme class

Theme for GSplitter

Inheritance

Constructors

GSplitterTheme({required PaintStyle lineStyle, required PaintStyle handleStyle, required PaintStyle handleLineStyle, double handleWidth = 60, double handleBorderRadius = 4})
const

Properties

handleBorderRadius double
final
handleLineStyle PaintStyle
final
handleStyle PaintStyle
final
handleWidth double
final
hashCode int
The hash code for this object.
no setterinherited
lineStyle PaintStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PaintStyle? lineStyle, PaintStyle? handleStyle, PaintStyle? handleLineStyle, double? handleWidth, double? handleBorderRadius}) GSplitterTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited