GTableLayout class

Implementers

Constructors

GTableLayout({required List<List<GTableItem>> items, List<GTableSpanItem> spanItems = const [], EdgeInsets padding = EdgeInsets.zero, EdgeInsets margin = EdgeInsets.zero})

Properties

colWidths List<double>
final
hashCode int
The hash code for this object.
no setterinherited
items List<List<GTableItem>>
List of rows, each containing a list of column items in that row
final
margin EdgeInsets
final
padding EdgeInsets
final
rowHeights List<double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
getter/setter pair
spanItemRectangles List<Rect>
final
spanItems List<GTableSpanItem>
span items that can span multiple rows and columns
final

Methods

layout() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited