GTooltip class

Tooltip component.

Inheritance

Constructors

GTooltip({GTooltipPosition position = GTooltipPosition.followPointer, bool showPointValue = true, List<String> dataKeys = const [], String? followValueKey, String? followValueViewPortId, bool pointLineHighlightVisible = true, bool valueLineHighlightVisible = true, GRender<GComponent<GComponentTheme>, GComponentTheme>? render = const GTooltipRender(), GComponentTheme? theme, GToolTipWidgetBuilder? tooltipWidgetBuilder})

Properties

dataKeys List<String>
the data keys which will be displayed in the tooltip.
final
followValueKey String?
getter/setter pair
followValueViewPortId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highlighted bool
getter/setter pairinherited
highlightedNotifier GValue<bool>
no setterinherited
hitTestEnable bool
no setterinherited
hitTestMode GHitTestMode
getter/setter pairinherited
hitTestModeNotifier GValue<GHitTestMode>
no setterinherited
id String?
Identifier of the component.
finalinherited
label String?
getter/setter pairinherited
labelNotifier GValue<String?>
no setterinherited
layer int
getter/setter pairinherited
layerNotifier GValue<int>
no setterinherited
locked bool
getter/setter pairinherited
lockedNotifier GValue<bool>
no setterinherited
pointLineHighlightVisible bool
getter/setter pair
position GTooltipPosition
getter/setter pair
render GRender<GComponent<GComponentTheme>, GComponentTheme>?
Render of the component.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
getter/setter pairinherited
selectedNotifier GValue<bool>
no setterinherited
showPointValue bool
getter/setter pair
theme GComponentTheme?
getter/setter pairinherited
tooltipNotifier ValueNotifier<GToolTipWidgetContext?>?
no setter
tooltipWidgetBuilder GToolTipWidgetBuilder?
getter/setter pair
valueLineHighlightVisible bool
getter/setter pair
visible bool
getter/setter pairinherited
visibleNotifier GValue<bool>
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
dispose() → void
getRender() GRender<GComponent<GComponentTheme>, GComponentTheme>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited