GTooltipTheme class

Theme for GTooltip component.

Inheritance

Constructors

GTooltipTheme({required PaintStyle frameStyle, required LabelStyle pointStyle, required LabelStyle labelStyle, required LabelStyle valueStyle, PaintStyle? pointHighlightStyle, PaintStyle? valueHighlightStyle, double frameCornerRadius = 2, double framePadding = 6, double frameMargin = 6, double labelValueSpacing = 16, double rowSpacing = 2, double pointRowSpacing = 6})
const

Properties

frameCornerRadius double
Radius of the tooltip frame corner.
final
frameMargin double
Margin of the tooltip frame.
final
framePadding double
Padding of the tooltip frame.
final
frameStyle PaintStyle
Style of the tooltip frame.
final
hashCode int
The hash code for this object.
no setterinherited
labelStyle LabelStyle
Style of the value label.
final
labelValueSpacing double
Spacing between label and value.
final
pointHighlightStyle PaintStyle?
Style of the highlighted point line/area.
final
pointRowSpacing double
Spacing between point row and the first value row.
final
pointStyle LabelStyle
Style of the point value.
final
rowSpacing double
Spacing between label & value rows.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueHighlightStyle PaintStyle?
Style of the highlighted value line.
final
valueStyle LabelStyle
Style of the value.
final

Methods

copyWith({PaintStyle? frameStyle, LabelStyle? pointStyle, LabelStyle? labelStyle, LabelStyle? valueStyle, PaintStyle? pointHighlightStyle, PaintStyle? valueHighlightStyle, double? frameCornerRadius, double? framePadding, double? frameMargin, double? labelValueSpacing, double? rowSpacing, double? pointRowSpacing}) GTooltipTheme
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited