GValueAxis class

value axis for vertical direction.

Inheritance

Constructors

GValueAxis({String? id, String viewPortId = "", GAxisPosition position = GAxisPosition.end, GAxisScaleMode scaleMode = GAxisScaleMode.zoom, double size = defaultVAxisSize, GValueTickerStrategy valueTickerStrategy = const GValueTickerStrategyDefault(), String valueFormatter(double value, int precision)?, List<GValueAxisMarker> axisMarkers = const [], List<GOverlayMarker> overlayMarkers = const [], GComponentTheme? theme, GRender<GComponent<GComponentTheme>, GComponentTheme>? render = const GValueAxisRender()})

Properties

axisMarkers List<GAxisMarker>
Axis markers
finalinherited
hashCode int
The hash code for this object.
no setterinherited
highlighted bool
getter/setter pairinherited
highlightedNotifier GValue<bool>
no setterinherited
hitTestEnable bool
no setterinherited
hitTestMode GHitTestMode
getter/setter pairinherited
hitTestModeNotifier GValue<GHitTestMode>
no setterinherited
id String?
Identifier of the component.
finalinherited
isAlignLeft bool
no setter
isAlignRight bool
no setter
label String?
getter/setter pairinherited
labelNotifier GValue<String?>
no setterinherited
layer int
getter/setter pairinherited
layerNotifier GValue<int>
no setterinherited
locked bool
getter/setter pairinherited
lockedNotifier GValue<bool>
no setterinherited
overlayMarkers List<GOverlayMarker>
Overlay markers on the axis.
finalinherited
position GAxisPosition
getter/setter pairinherited
render GRender<GComponent<GComponentTheme>, GComponentTheme>?
Render of the component.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleMode GAxisScaleMode
getter/setter pairinherited
selected bool
getter/setter pairinherited
selectedNotifier GValue<bool>
no setterinherited
size double
getter/setter pairinherited
theme GComponentTheme?
getter/setter pairinherited
valueFormatter String Function(double value, int precision)?
The formatter to format the value.
final
valueTickerStrategy GValueTickerStrategy
The strategy to calculate the value ticks.
final
viewPortId String
The value view port id of the value axis.
final
visible bool
getter/setter pairinherited
visibleNotifier GValue<bool>
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
getRender() GRender<GComponent<GComponentTheme>, GComponentTheme>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
placeTo(Rect area) → (Rect, Rect)
place the axis to the given area and return the areas of the axis (areaAxis) and the area left (areaLeft).
override
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited