GViewPortResizeMode enum

Defines the behavior of how to update the viewport range when view size changed.

Inheritance
Available extensions

Values

keepRange → const GViewPortResizeMode

no update to the range

keepStart → const GViewPortResizeMode

keep the range start of the viewport and extend / shrink the range end

keepEnd → const GViewPortResizeMode

keep the range end of the viewport and extend / shrink the range start

keepCenter → const GViewPortResizeMode

keep the range center of the viewport and extend / shrink the range start and end

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GViewPortResizeMode>
A constant List of the values in this enum, in order of their declaration.