EllipseUtil class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
distanceTo(double cx, double cy, double a, double b, double px, double py)
→ double
-
-
hitTest({required double cx, required double cy, required double rx, required double ry, required double px, required double py, bool testArea = false, double epsilon = 5.0})
→ bool
-
-
isInside(double cx, double cy, double a, double b, double px, double py)
→ bool
-
-
nearestPointOn(Vector2 point, double left, double top, double right, double bottom, {double rotationTheta = 0, double stopScanDistance = 1})
→ Vector2
-
-
pointOnEllipse(double cx, double cy, double a, double b, double t)
→ Vector2
-
-
pointOnEllipseRotated(double cx, double cy, double a, double b, double t, double theta)
→ Vector2
-