GPolyLineMarker class
- Inheritance
-
- Object
- GComponent<
GComponentTheme> - GMarker
- GOverlayMarker
- GPolyLineMarker
Constructors
-
GPolyLineMarker({String? id, String? label, bool visible = true, int layer = kDefaultLayer, GHitTestMode hitTestMode = GHitTestMode.auto, GOverlayMarkerTheme? theme, required List<
GCoordinate> coordinates, GOverlayMarkerRender<GOverlayMarker, GOverlayMarkerTheme> ? render, GOverlayMarkerScaleHandler<GOverlayMarker> ? scaleHandler})
Properties
-
coordinates
→ List<
GCoordinate> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlighted ↔ bool
-
getter/setter pairinherited
-
highlightedNotifier
→ GValue<
bool> -
no setterinherited
- hitTestEnable → bool
-
no setterinherited
- hitTestMode ↔ GHitTestMode
-
getter/setter pairinherited
-
hitTestModeNotifier
→ GValue<
GHitTestMode> -
no setterinherited
- id → String?
-
Identifier of the component.
finalinherited
-
keyCoordinates
→ List<
GCoordinate> -
Key points decides the shape of the marker.
finalinherited
- label ↔ String?
-
getter/setter pairinherited
-
labelNotifier
→ GValue<
String?> -
no setterinherited
- layer ↔ int
-
getter/setter pairinherited
-
layerNotifier
→ GValue<
int> -
no setterinherited
- locked ↔ bool
-
getter/setter pairinherited
-
lockedNotifier
→ GValue<
bool> -
no setterinherited
-
render
↔ GRender<
GComponent< ?GComponentTheme> , GComponentTheme> -
Render of the component.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaleHandler
↔ GOverlayMarkerScaleHandler<
GOverlayMarker> ? -
getter/setter pairinherited
- selected ↔ bool
-
getter/setter pairinherited
-
selectedNotifier
→ GValue<
bool> -
no setterinherited
- theme ↔ GOverlayMarkerTheme?
-
getter/setter pairinherited
- visible ↔ bool
-
getter/setter pairinherited
-
visibleNotifier
→ GValue<
bool> -
no setterinherited
Methods
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getRender(
) → GOverlayMarkerRender< GOverlayMarker, GOverlayMarkerTheme> -
inherited
-
hitTest(
{required Offset position, double? epsilon, dynamic autoHighlight = true}) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited